@@ -1,11 +1,6 @@
 
-from abc import ABCMeta
-from uk_dataset import UK
-from global_dataset import Global
-
-
-class Source(metaclass=ABCMeta):
-    pass
+from client.uk_dataset import UK
+from client.global_dataset import Global
 
 
 class LightcastSmartDataset():
@@ -32,5 +27,3 @@ class LightcastSmartDataset():
 
     def globalDataset(self) -> Global:
         return Global(self.__username, self.__password)
-
-
